==> af-common-file-2.12.0-sources.jar: com/af/v4/system/common/file/service/FileService.java <==
package com.af.v4.system.common.file.service;

import com.af.v4.system.api.model.LoginUser;
import com.af.v4.system.common.core.constant.FileConstants;
import com.af.v4.system.common.core.exception.ServiceException;
import com.af.v4.system.common.core.proxy.jpa.IEntityServiceProxy;
import com.af.v4.system.common.core.service.ApplicationService;
import com.af.v4.system.common.file.entity.TextMultipartFile;
import com.af.v4.system.common.file.entity.UploadFileInfo;
import com.af.v4.system.common.file.enums.ResUploadModeEnum;
import com.af.v4.system.common.file.utils.FilePathUtil;
import com.af.v4.system.common.plugins.core.CalculateUtil;
import com.af.v4.system.common.plugins.core.CommonTools;
import com.af.v4.system.common.plugins.core.ConvertTools;
import com.af.v4.system.common.security.utils.SecurityUtils;
import org.apache.commons.io.FileUtils;
import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/**
 * 文件处理服务
 *
 * @author Mr.river
 */
@Service
public class FileService {
    private static final Logger LOGGER = LoggerFactory.getLogger(FileService.class);
    private final IEntityServiceProxy entityService;
    private final MinioService minioService;
    private final ApplicationService applicationService;
    private final FilePathUtil filePathUtil;

    public FileService(IEntityServiceProxy entityService, MinioService minioService, ApplicationService applicationService, FilePathUtil filePathUtil) {
        this.entityService = entityService;
        this.minioService = minioService;
        this.applicationService = applicationService;
        this.filePathUtil = filePathUtil;
    }


    /**
     * 文件上传
     *
     * @param file          文件
     * @param resUploadMode 资源上传模式
     * @param operator      操作人
     * @param formType      表单类型
     * @param useType       附件用途
     * @param bucketName    minio 桶名
     * @param saveName      保存文件名
     * @return 响应
     */
    public FileUploadResult uploadFile(MultipartFile file, String resUploadMode, String operator, String formType, String useType, String bucketName, String saveName) {
        ResUploadModeEnum resUploadTypeEnum = ResUploadModeEnum.toType(resUploadMode);
        if (resUploadTypeEnum == null) {
            throw new ServiceException("不支持该资源上传类型：" + resUploadMode);
        }
        // 文件名称
        String fileName = file.getOriginalFilename();
        assert fileName != null;

        UploadFileInfo fileInfo = new UploadFileInfo();
        // 文件大小
        fileInfo.setSize(CalculateUtil.div(file.getSize(), 1024 * 1024, 4));
        // 文件后缀名
        fileInfo.setExtension(FilePathUtil.fileExt(fileName));
        // 解析扩展名称对应的系统资源类型
        fileInfo.setResourceType(FileConstants.RESOURCE_EXT_2_TYPE.get(fileInfo.getExtension()));
        // 检测是否为系统不支持的资源类型
        if (fileInfo.getResourceType() == null) {
            throw new ServiceException("当前资源类型不支持上传：" + fileInfo.getExtension());
        }
        // 上传原文件的文件名
        fileInfo.setOriginalName(fileName.replaceAll("(?i)." + fileInfo.getExtension(), ""));
        // 自定义新的存储文件名
        fileInfo.setSaveName(Objects.requireNonNullElseGet(saveName, () -> CommonTools.getUUID(true) + "." + fileInfo.getExtension()));
        FileUploadResult result;
        // 根据不同的文件上传模式，上传文件
        switch (resUploadTypeEnum) {
            case SERVER -> {
                fileInfo.setExtraPath(filePathUtil.getFileExtraPathByServer(fileInfo.getResourceType()));
                fileInfo.setSavePath(filePathUtil.getFileFullPathByServer(fileInfo.getResourceType(), fileInfo.getSaveName()));
                Map<String, Object> entity = uploadFileToServer(file, fileInfo, operator, formType, useType);
                result = new FileUploadResult(true, entity);
            }
            case BASE64 -> {
                Map<String, Object> entity = uploadFileToBase64(file);
                result = new FileUploadResult(true, entity);
            }
            default -> {
                fileInfo.setExtraPath(filePathUtil.getFileExtraPathBySSO(fileInfo.getResourceType(), bucketName));
                fileInfo.setSavePath(filePathUtil.getFileFullPathBySSO(fileInfo.getResourceType(), fileInfo.getSaveName(), bucketName));
                Map<String, Object> entity = uploadFileToOSS(file, fileInfo, operator, formType, useType, bucketName);
                result = new FileUploadResult(true, entity);
            }
        }
        return result;
    }

    public FileUploadResult uploadFile(MultipartFile file, String resUploadMode, String operator, String formType, String useType) {
        return uploadFile(file, resUploadMode, operator, formType, useType, null, null);
    }

    public FileUploadResult uploadFile(MultipartFile file, String resUploadMode) {
        return uploadFile(file, resUploadMode, null, null, null);
    }

    /**
     * 上传纯文本格式的文件
     *
     * @param content       字符串文本
     * @param fileName      文件名
     * @param resUploadMode 资源上传模式
     * @param operator      操作人
     * @param formType      表单类型
     * @param useType       附件用途
     * @param bucketName    minio 桶名
     * @param saveName      保存文件名
     * @return 响应
     */
    public FileUploadResult uploadText(String content, String fileName, String resUploadMode, String operator, String formType, String useType, String bucketName, String saveName) {
        // 将 字符串文本 转为 MultipartFile
        MultipartFile file = new TextMultipartFile(fileName, content);
        return uploadFile(file, resUploadMode, operator, formType, useType, bucketName, saveName);
    }

    public FileUploadResult uploadText(String content, String fileName, String resUploadMode) {
        return uploadText(content, fileName, resUploadMode, null, null, null, null, null);
    }

    /**
     * 上传文件到服务器
     *
     * @param file     文件对象
     * @param fileInfo 文件实体
     * @param operator 操作人
     * @param formType 表单类型
     * @param useType  用途
     * @return t_files实体
     */
    private Map<String, Object> uploadFileToServer(MultipartFile file, UploadFileInfo fileInfo, String operator, String formType, String useType) {
        String path = fileInfo.getSavePath();
        File fileDir = new File(path);
        // 写入文件
        try {
            FileUtils.copyInputStreamToFile(file.getInputStream(), fileDir);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        String downloadPath = filePathUtil.getFileDownloadUrlByServer(fileInfo.getResourceType(), fileInfo.getSaveName());
        return saveFileEntity(ResUploadModeEnum.SERVER, fileInfo, downloadPath, path, operator, formType, useType);
    }

    /**
     * 上传文件为base64串
     *
     * @param file 文件
     * @return 结果
     */
    private Map<String, Object> uploadFileToBase64(MultipartFile file) {
        try {
            Map<String, Object> message = new HashMap<>(1);
            message.put("base64", ConvertTools.base64Encode(file.getBytes()));
            return message;
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 上传文件到OSS
     *
     * @param file       文件
     * @param fileInfo   文件实体
     * @param operator   操作人
     * @param formType   表单类型
     * @param useType    用途
     * @param bucketName minio 桶名
     * @return 结果
     */
    private Map<String, Object> uploadFileToOSS(MultipartFile file, UploadFileInfo fileInfo, String operator, String formType, String useType, String bucketName) {
        if (bucketName == null) {
            bucketName = applicationService.getApplicationName();
        }
        try {
            minioService.upload(file, fileInfo.getSavePath(), bucketName);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
        String downloadPath = filePathUtil.getFileDownloadUrlBySSO(fileInfo.getResourceType(), fileInfo.getSaveName(), bucketName);
        return saveFileEntity(ResUploadModeEnum.OSS, fileInfo, downloadPath, fileInfo.getSavePath(), operator, formType, useType);
    }

    /**
     * 删除文件
     *
     * @param id            文件资源ID
     * @param resUploadMode 资源上传时模式
     * @return 文件上传结果
     */
    public FileUploadResult deleteFile(Integer id, String resUploadMode) {
        ResUploadModeEnum resUploadTypeEnum = ResUploadModeEnum.toType(resUploadMode);
        FileUploadResult result;
        if (resUploadTypeEnum == null) {
            throw new ServiceException("不支持该资源上传类型：" + resUploadMode);
        }
        JSONObject row = new JSONObject();
        row.put("id", id);
        row.put("f_state", "删除");
        JSONObject entityResult = entityService.partialSave("t_files", row);
        result = new FileUploadResult(true, entityResult.toMap());
        // 根据不同的文件上传模式，删除文件
        switch (resUploadTypeEnum) {
            case SERVER -> {
                // TODO
            }
            case BASE64 -> {
                // TODO
            }
            default -> {
                // TODO
            }
        }
        return result;
    }

    private Map<String, Object> saveFileEntity(ResUploadModeEnum resUploadModeEnum, UploadFileInfo fileInfo, String downloadPath, String realPath, String operator, String formType, String useType) {
        JSONObject filesEntity = new JSONObject();

        if (operator == null) {
            LoginUser loginUser = SecurityUtils.getLoginUser();
            if (loginUser != null) {
                operator = loginUser.getUsername();
            }
        }

        if (useType == null) {
            useType = "Default";
        }

        if (formType == null) {
            formType = "file";
        }

        filesEntity.put("f_filename", fileInfo.getSaveName());        // 保存的文件名
        filesEntity.put("f_stock_id", 0);                            // 库存ID(固定为0)
        filesEntity.put("f_filetype", fileInfo.getExtension());      // 文件类型(扩展名)
        filesEntity.put("f_downloadpath", downloadPath);             // 下载路径
        filesEntity.put("f_realpath", realPath);                     // 实际存储路径
        filesEntity.put("f_file_size", fileInfo.getSize());         // 文件大小
        filesEntity.put("f_operator", operator);                     // 操作人
        filesEntity.put("f_form_type", formType);                   // 表单类型
        filesEntity.put("f_type", fileInfo.getResourceType());      // 资源类型
        filesEntity.put("f_use_type", useType);                     // 使用类型
        filesEntity.put("f_upload_mode", resUploadModeEnum.getValue()); // 上传模式(这里是"oss")
        filesEntity.put("fusetype", useType);                       // 使用类型(冗余字段)

        // 保存记录到数据库并返回id
        filesEntity.put("id", entityService.partialSave("t_files", filesEntity).getString("id"));

        return filesEntity.toMap();
    }

    /**
     * 文件上传结果
     */
    public static class FileUploadResult {

        /**
         * 是否成功
         */
        private final Boolean isSuccess;
        /**
         * 响应数据
         */
        private final Map<String, Object> data;

        private FileUploadResult(boolean isSuccess, Map<String, Object> data) {
            this.isSuccess = isSuccess;
            this.data = data;
        }

        public Boolean getSuccess() {
            return isSuccess;
        }

        public Object getData() {
            return data;
        }

        public JSONObject toJson() {
            return new JSONObject()
                    .put("isSuccess", isSuccess)
                    .put("data", data);
        }
    }
}

==> af-common-file-2.12.9-sources.jar: com/af/v4/system/common/file/service/FileService.java <==
package com.af.v4.system.common.file.service;

import com.af.v4.system.api.model.LoginUser;
import com.af.v4.system.common.core.constant.FileConstants;
import com.af.v4.system.common.core.exception.ServiceException;
import com.af.v4.system.common.core.proxy.jpa.IEntityServiceProxy;
import com.af.v4.system.common.core.service.ApplicationService;
import com.af.v4.system.common.file.entity.TextMultipartFile;
import com.af.v4.system.common.file.entity.UploadFileInfo;
import com.af.v4.system.common.file.enums.ResUploadModeEnum;
import com.af.v4.system.common.file.utils.FilePathUtil;
import com.af.v4.system.common.plugins.core.CalculateUtil;
import com.af.v4.system.common.plugins.core.CommonTools;
import com.af.v4.system.common.plugins.core.ConvertTools;
import com.af.v4.system.common.security.utils.SecurityUtils;
import org.apache.commons.io.FileUtils;
import org.apache.commons.io.FilenameUtils;
import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/**
 * 文件处理服务
 *
 * @author Mr.river
 */
@Service
public class FileService {
    private static final Logger LOGGER = LoggerFactory.getLogger(FileService.class);
    private final IEntityServiceProxy entityService;
    private final MinioService minioService;
    private final ApplicationService applicationService;
    private final FilePathUtil filePathUtil;

    public FileService(IEntityServiceProxy entityService, MinioService minioService, ApplicationService applicationService, FilePathUtil filePathUtil) {
        this.entityService = entityService;
        this.minioService = minioService;
        this.applicationService = applicationService;
        this.filePathUtil = filePathUtil;
    }


    /**
     * 文件上传
     *
     * @param file          文件
     * @param resUploadMode 资源上传模式
     * @param operator      操作人
     * @param formType      表单类型
     * @param useType       附件用途
     * @param bucketName    minio 桶名
     * @param saveName      保存文件名
     * @return 响应
     */
    public FileUploadResult uploadFile(MultipartFile file, String resUploadMode, String operator, String formType, String useType, String bucketName, String saveName) {
        ResUploadModeEnum resUploadTypeEnum = ResUploadModeEnum.toType(resUploadMode);
        if (resUploadTypeEnum == null) {
            throw new ServiceException("不支持该资源上传类型：" + resUploadMode);
        }
        // 文件名称
        String fileName = file.getOriginalFilename();
        assert fileName != null;

        UploadFileInfo fileInfo = new UploadFileInfo();
        // 文件大小
        fileInfo.setSize(CalculateUtil.div(file.getSize(), 1024 * 1024, 4));
        // 文件后缀名
        fileInfo.setExtension(FilePathUtil.fileExt(fileName));
        // 解析扩展名称对应的系统资源类型
        fileInfo.setResourceType(FileConstants.RESOURCE_EXT_2_TYPE.get(fileInfo.getExtension()));
        // 检测是否为系统不支持的资源类型
        if (fileInfo.getResourceType() == null) {
            throw new ServiceException("当前资源类型不支持上传：" + fileInfo.getExtension());
        }
        // 上传原文件的文件名
        fileInfo.setOriginalName(fileName);
        // 自定义新的存储文件名
        fileInfo.setSaveName(Objects.requireNonNullElseGet(saveName, () -> CommonTools.getUUID(true) + "." + fileInfo.getExtension()));
        FileUploadResult result;
        // 根据不同的文件上传模式，上传文件
        switch (resUploadTypeEnum) {
            case SERVER -> {
                fileInfo.setExtraPath(filePathUtil.getFileExtraPathByServer(fileInfo.getResourceType()));
                fileInfo.setSavePath(filePathUtil.getFileFullPathByServer(fileInfo.getResourceType(), fileInfo.getSaveName()));
                Map<String, Object> entity = uploadFileToServer(file, fileInfo, operator, formType, useType);
                result = new FileUploadResult(true, entity);
            }
            case BASE64 -> {
                Map<String, Object> entity = uploadFileToBase64(file);
                result = new FileUploadResult(true, entity);
            }
            default -> {
                fileInfo.setExtraPath(filePathUtil.getFileExtraPathBySSO(fileInfo.getResourceType(), bucketName));
                fileInfo.setSavePath(filePathUtil.getFileFullPathBySSO(fileInfo.getResourceType(), fileInfo.getSaveName(), bucketName));
                Map<String, Object> entity = uploadFileToOSS(file, fileInfo, operator, formType, useType, bucketName);
                result = new FileUploadResult(true, entity);
            }
        }
        return result;
    }

    public FileUploadResult uploadFile(MultipartFile file, String resUploadMode, String operator, String formType, String useType) {
        return uploadFile(file, resUploadMode, operator, formType, useType, null, null);
    }

    public FileUploadResult uploadFile(MultipartFile file, String resUploadMode) {
        return uploadFile(file, resUploadMode, null, null, null);
    }

    /**
     * 上传纯文本格式的文件
     *
     * @param content       字符串文本
     * @param fileName      文件名
     * @param resUploadMode 资源上传模式
     * @param operator      操作人
     * @param formType      表单类型
     * @param useType       附件用途
     * @param bucketName    minio 桶名
     * @param saveName      保存文件名
     * @return 响应
     */
    public FileUploadResult uploadText(String content, String fileName, String resUploadMode, String operator, String formType, String useType, String bucketName, String saveName) {
        // 将 字符串文本 转为 MultipartFile
        MultipartFile file = new TextMultipartFile(fileName, content);
        return uploadFile(file, resUploadMode, operator, formType, useType, bucketName, saveName);
    }

    public FileUploadResult uploadText(String content, String fileName, String resUploadMode) {
        return uploadText(content, fileName, resUploadMode, null, null, null, null, null);
    }

    /**
     * 上传文件到服务器
     *
     * @param file     文件对象
     * @param fileInfo 文件实体
     * @param operator 操作人
     * @param formType 表单类型
     * @param useType  用途
     * @return t_files实体
     */
    private Map<String, Object> uploadFileToServer(MultipartFile file, UploadFileInfo fileInfo, String operator, String formType, String useType) {
        String path = fileInfo.getSavePath();
        File fileDir = new File(path);
        // 写入文件
        try {
            FileUtils.copyInputStreamToFile(file.getInputStream(), fileDir);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        String downloadPath = filePathUtil.getFileDownloadUrlByServer(fileInfo.getResourceType(), fileInfo.getSaveName());
        return saveFileEntity(ResUploadModeEnum.SERVER, fileInfo, downloadPath, path, operator, formType, useType);
    }

    /**
     * 上传文件为base64串
     *
     * @param file 文件
     * @return 结果
     */
    private Map<String, Object> uploadFileToBase64(MultipartFile file) {
        try {
            Map<String, Object> message = new HashMap<>(1);
            message.put("base64", ConvertTools.base64Encode(file.getBytes()));
            return message;
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 上传文件到OSS
     *
     * @param file       文件
     * @param fileInfo   文件实体
     * @param operator   操作人
     * @param formType   表单类型
     * @param useType    用途
     * @param bucketName minio 桶名
     * @return 结果
     */
    private Map<String, Object> uploadFileToOSS(MultipartFile file, UploadFileInfo fileInfo, String operator, String formType, String useType, String bucketName) {
        if (bucketName == null) {
            bucketName = applicationService.getApplicationName();
        }
        try {
            minioService.upload(file, fileInfo.getSavePath(), bucketName);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
        String downloadPath = filePathUtil.getFileDownloadUrlBySSO(fileInfo.getResourceType(), fileInfo.getSaveName(), bucketName);
        return saveFileEntity(ResUploadModeEnum.OSS, fileInfo, downloadPath, fileInfo.getSavePath(), operator, formType, useType);
    }

    /**
     * 删除文件
     *
     * @param id            文件资源ID
     * @param resUploadMode 资源上传时模式
     * @return 文件上传结果
     */
    public FileUploadResult deleteFile(Integer id, String resUploadMode) {
        ResUploadModeEnum resUploadTypeEnum = ResUploadModeEnum.toType(resUploadMode);
        FileUploadResult result;
        if (resUploadTypeEnum == null) {
            throw new ServiceException("不支持该资源上传类型：" + resUploadMode);
        }
        JSONObject row = new JSONObject();
        row.put("id", id);
        row.put("f_state", "删除");
        JSONObject entityResult = entityService.partialSave("t_files", row);
        result = new FileUploadResult(true, entityResult.toMap());
        // 根据不同的文件上传模式，删除文件
        switch (resUploadTypeEnum) {
            case SERVER -> {
                // TODO
            }
            case BASE64 -> {
                // TODO
            }
            default -> {
                // TODO
            }
        }
        return result;
    }

    private Map<String, Object> saveFileEntity(ResUploadModeEnum resUploadModeEnum, UploadFileInfo fileInfo, String downloadPath, String realPath, String operator, String formType, String useType) {
        JSONObject filesEntity = new JSONObject();

        if (operator == null) {
            LoginUser loginUser = SecurityUtils.getLoginUser();
            if (loginUser != null) {
                operator = loginUser.getUsername();
            }
        }

        if (useType == null) {
            useType = "Default";
        }

        if (formType == null) {
            formType = "file";
        }

        filesEntity.put("f_filename", fileInfo.getSaveName());        // 保存的文件名
        filesEntity.put("f_real_name",fileInfo.getOriginalName());    // 原始文件名
        filesEntity.put("f_stock_id", 0);                             // 库存ID(固定为0)
        filesEntity.put("f_filetype", fileInfo.getExtension());       // 文件类型(扩展名)
        filesEntity.put("f_downloadpath", downloadPath);              // 下载路径
        filesEntity.put("f_realpath", realPath);                      // 实际存储路径
        filesEntity.put("f_file_size", fileInfo.getSize());           // 文件大小
        filesEntity.put("f_operator", operator);                      // 操作人
        filesEntity.put("f_form_type", formType);                     // 表单类型
        filesEntity.put("f_type", fileInfo.getResourceType());        // 资源类型
        filesEntity.put("f_use_type", useType);                       // 使用类型
        filesEntity.put("f_upload_mode", resUploadModeEnum.getValue()); // 上传模式(这里是"oss")
        filesEntity.put("fusetype", useType);                         // 使用类型(冗余字段)

        // 保存记录到数据库并返回id
        filesEntity.put("id", entityService.partialSave("t_files", filesEntity).getString("id"));

        return filesEntity.toMap();
    }

    /**
     * 文件上传结果
     */
    public static class FileUploadResult {

        /**
         * 是否成功
         */
        private final Boolean isSuccess;
        /**
         * 响应数据
         */
        private final Map<String, Object> data;

        private FileUploadResult(boolean isSuccess, Map<String, Object> data) {
            this.isSuccess = isSuccess;
            this.data = data;
        }

        public Boolean getSuccess() {
            return isSuccess;
        }

        public Object getData() {
            return data;
        }

        public JSONObject toJson() {
            return new JSONObject()
                    .put("isSuccess", isSuccess)
                    .put("data", data);
        }
    }
}
